import{O as l}from"./workspaceStore-CRQkfLa2.js";import{a as c,J as f,k as u,h as n,w as o,u as t,ao as _,T as b,g as r,t as i,i as s,f as p}from"./jwt-decode.esm-Dzy-9m8i.js";import"./userStore-Drxc-3f9.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a8ff9bbd-42de-4d7c-9aa3-437bf544a978",e._sentryDebugIdIdentifier="sentry-dbid-a8ff9bbd-42de-4d7c-9aa3-437bf544a978")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(a,d)=>(p(),u("div",null,[n(t(_),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(t(b),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-P0nvN0ke.js.map
