import{i as h}from"./metadata-CuQD6dTE.js";import{W as b}from"./Watermark-DU3ArgNw.js";import{F as w}from"./PhArrowSquareOut.vue-DffoWKMw.js";import{a as v,c as x,r as C,k as f,e as D,u as e,h as p,w as s,F as u,b as r,g as y,t as _,i as I,b2 as g,R as z,$ as F,af as B,f as a,K as L,Y as N,aO as S}from"./jwt-decode.esm-Dzy-9m8i.js";import{u as T}from"./workspaceStore-CRQkfLa2.js";import{C as V}from"./index-CfTFGoKH.js";import{L as W}from"./LoadingOutlined-hmWUJiw2.js";import"./PhMagnifyingGlass.vue-BEtusSZR.js";import"./PhWebhooksLogo.vue-_naOH9ua.js";import"./constants-CWkAmIyV.js";import"./userStore-Drxc-3f9.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="0a7d8c85-e65a-483e-b7b9-f486eecfb809",o._sentryDebugIdIdentifier="sentry-dbid-0a7d8c85-e65a-483e-b7b9-f486eecfb809")}catch{}})();const $={key:0,class:"home-container"},E=v({__name:"Home",setup(o){const n=B(),i=T(),d=x(()=>i.state.workspace?.sidebar.filter(c=>c.id!=="home")||[]),l=C(null),k=async(c,m)=>{l.value=m,await n.push({path:`/${c}`}),l.value=null};return(c,m)=>e(i).state.workspace?(a(),f("div",$,[p(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[d.value.length===0?(a(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),f(z,{key:1},F(d.value,t=>(a(),r(e(V),{key:t.id,class:L(["form-card",{loading:l.value===t.id}]),"body-style":{cursor:"pointer"},onClick:H=>k(t.path,t.id)},{default:s(()=>[p(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(a(),r(N(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(_(t.name),1)]),_:2},1024),l.value!==t.id?(a(),r(e(w),{key:0,size:"20"})):(a(),r(e(W),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(b,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):D("",!0)}}),Z=S(E,[["__scopeId","data-v-2dd12c4e"]]);export{Z as default};
//# sourceMappingURL=Home-eiAcK0Zt.js.map
