import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-DACb9zR8.js";import{B as y}from"./BaseLayout-D4WcKyJr.js";import{a as l,W as _,a5 as b,aO as u,aK as v,aL as g,f,k as h,n as o,Q as s,J as w,af as S,b as k,w as n,ak as B,h as i,u as I}from"./jwt-decode.esm-Dzy-9m8i.js";import{u as L}from"./editor-C60E4jG8.js";import{A as $}from"./index-Ca3RhZ0a.js";import"./logo-BiWG9_W5.js";import"./Logo-1eOfZ7jQ.js";import"./router-CPHOdpsP.js";import"./userStore-Drxc-3f9.js";import"./workspaceStore-CRQkfLa2.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";import"./useCodebaseEvents-DDGWyxw3.js";import"./contracts.generated-xEtU3F0o.js";import"./ts.worker-DQrt9nOI.js";import"./constants-CWkAmIyV.js";import"./linters-DvFQho0g.js";import"./asyncComputed-Ab6ltgBh.js";import"./index-BliR2HIx.js";import"./index-BAH-OJNC.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="4bbf5a6a-fe63-4cad-b1c1-695625098b1c",e._sentryDebugIdIdentifier="sentry-dbid-4bbf5a6a-fe63-4cad-b1c1-695625098b1c")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function K(e,r,a,c,d,p){return v((f(),h("div",D,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-06538001"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),c=L();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){a.push({name:"error"});return}await c.createLogin(t).then(d),a.push({name:"editor"})}),(t,A)=>(f(),k(y,null,{navbar:n(()=>[i(I($),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[o("div",R,[i(P)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-d2a19803"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-D68qxML0.js.map
