.table-card[data-v-85028b3c]{height:100%;width:100%;transition:all .3s ease}.table-card[data-v-85028b3c]:hover{transform:translateY(-2px);box-shadow:0 4px 12px #00000026}.columns-list[data-v-85028b3c]{max-height:280px;overflow-y:auto;overflow-x:hidden}.column-row[data-v-85028b3c]{padding:4px 0;position:relative;min-width:0;transition:all .2s ease}.column-highlighted[data-v-85028b3c],.more-columns-highlighted[data-v-85028b3c]{background-color:#e6f7ff}.table-highlighted[data-v-85028b3c]{border:2px solid #1890ff;box-shadow:0 0 0 2px #1890ff33}.key-icon[data-v-85028b3c]{color:#faad14;flex-shrink:0}.delete-btn[data-v-85028b3c]{opacity:0;background:none;border:none;padding:4px;cursor:pointer;color:#9ca3af;border-radius:4px;display:flex;align-items:center;justify-content:center;transition:all .2s ease}.delete-btn[data-v-85028b3c]:hover{color:#ef4444;background-color:#fee2e2}.table-card:hover .delete-btn[data-v-85028b3c]{opacity:1}.type-tag[data-v-85028b3c]{font-size:11px;padding:0 8px;margin:0;border-radius:4px;white-space:nowrap;flex-shrink:0}
