import{a as t,k as s,f as o,h as d,u as r,b7 as f,aO as c}from"./jwt-decode.esm-Dzy-9m8i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="33105a4a-1400-4c14-8aa2-38f29d59fefb",e._sentryDebugIdIdentifier="sentry-dbid-33105a4a-1400-4c14-8aa2-38f29d59fefb")}catch{}})();const i={class:"centered"},_=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(f))]))}}),u=c(_,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer-fxVpr7yD.js.map
