import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-Dj9-B2IV.js";import{a as i,k as u,h as d,u as n,af as f,ak as m,f as l,aO as _}from"./jwt-decode.esm-Dzy-9m8i.js";import{u as b}from"./workspaceStore-CRQkfLa2.js";import"./OTPInput-CO9ifg8r.js";import"./Logo-1eOfZ7jQ.js";import"./string-CBgg-bcW.js";import"./CircularLoading-Bhmkz1og.js";import"./index-k7fKvFYe.js";import"./userStore-Drxc-3f9.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3b010cfb-ef8f-4392-afa0-196ccaad7c08",e._sentryDebugIdIdentifier="sentry-dbid-3b010cfb-ef8f-4392-afa0-196ccaad7c08")}catch{}})();const g={class:"runner"},y=i({__name:"Login",setup(e){const o=f(),a=m(),r=b(),c=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(l(),u("div",g,[d(p,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-DF1OhGt_.js.map
