import{A as n}from"./index-ByyrlDA1.js";import{a,c as o,k as r,e as f,K as c,h as l,u as p,f as d,aO as i}from"./jwt-decode.esm-Dzy-9m8i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="82e664f0-6b87-4200-b6e0-b2687e2a12b6",e._sentryDebugIdIdentifier="sentry-dbid-82e664f0-6b87-4200-b6e0-b2687e2a12b6")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(b,m)=>e.stepsInfo?(d(),r("nav",{key:0,class:c(["p-steps",{"full-screen":!e.isPreview}])},[l(p(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):f("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-Cs5OBdle.js.map
