import{L as u}from"./CircularLoading-Bhmkz1og.js";import{a as f,ak as p,J as h,k as _,f as l,n as d,h as g,aO as m}from"./jwt-decode.esm-Dzy-9m8i.js";import{E as a,a as y}from"./router-DFKMVA7Q.js";import"./ts.worker-DQrt9nOI.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="52138e4c-a66c-4337-9325-7e08c30b4efd",t._sentryDebugIdIdentifier="sentry-dbid-52138e4c-a66c-4337-9325-7e08c30b4efd")}catch{}})();const w={class:"authorize"},b={class:"content"},A=f({__name:"Authorize",setup(t){const o=p();return h(()=>{const{client_id:r,redirect_uri:s,response_type:n,state:i}=o.query,e=a.cloudApi.startsWith("https://")||a.cloudApi.startsWith("http://")?new URL(`${a.cloudApi}/oauth/authorize`):new URL(`${location.origin}${a.cloudApi}/oauth/authorize`);typeof r=="string"&&e.searchParams.set("client_id",r),typeof s=="string"&&e.searchParams.set("redirect_uri",s),typeof n=="string"&&e.searchParams.set("response_type",n),typeof i=="string"&&e.searchParams.set("state",i);const c=y.getAuthor();c?.jwt&&e.searchParams.set("session_token",c.jwt),window.location.href=e.toString()}),(r,s)=>(l(),_("div",w,[d("div",b,[s[0]||(s[0]=d("h1",null,"Authorizing...",-1)),g(u)])]))}}),L=m(A,[["__scopeId","data-v-57fe5408"]]);export{L as default};
//# sourceMappingURL=Authorize-Cie7oiPE.js.map
