import{a as l,c as o,k as t,e as r,K as d,t as f,bc as u,f as s,aO as g}from"./jwt-decode.esm-Dzy-9m8i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4f1aa6ca-718e-4b11-a871-ec172ca725f2",e._sentryDebugIdIdentifier="sentry-dbid-4f1aa6ca-718e-4b11-a871-ec172ca725f2")}catch{}})();const m={class:"logo"},b=["src","alt"],y=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){u(i=>({v4521d904:n.value}));const a=e,n=o(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),c=o(()=>`${a.brandName} Logo`);return(i,p)=>(s(),t("div",m,[e.imageUrl?(s(),t("img",{key:0,class:"logo-img",src:e.imageUrl,alt:c.value},null,8,b)):r("",!0),e.hideText?r("",!0):(s(),t("span",{key:1,class:d(e.size)},f(e.brandName),3))]))}}),_=g(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-1eOfZ7jQ.js.map
