import{N as l}from"./Navbar-CTLhWTxM.js";import{B as f}from"./BaseLayout-D4WcKyJr.js";import{C as _}from"./ContentLayout-CroNixph.js";import{a as g,ak as b,c as r,a8 as v,b as a,f as i,w as n,h as d,e as y}from"./jwt-decode.esm-Dzy-9m8i.js";import{_ as w}from"./BillingAlert.vue_vue_type_script_setup_true_lang-DEXzJjBD.js";import{u as z}from"./projectsStore-CxD5sZN1.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-CJhf1W-o.js";import"./constants-CWkAmIyV.js";import"./PhTranslate.vue-tUInk59v.js";import"./PhPencilSimple.vue-DkfZuL00.js";import"./router-DFKMVA7Q.js";import"./ts.worker-DQrt9nOI.js";import"./organization-ZhAJhUgH.js";import"./project-C7WgQejA.js";import"./record-BJeTf0YU.js";import"./tables-B--iEE7v.js";import"./string-CBgg-bcW.js";import"./organizationSwitcher-Dx4c2c2j.js";import"./folder-BGfuVCIP.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-Du5AGbMh.js";import"./member-CcWWIIlO.js";import"./index-CXO6xSyY.js";import"./index-CfTFGoKH.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-CVw0DjCx.js";import"./PhSignOut.vue-BQrRnmv-.js";import"./index-BliR2HIx.js";import"./index-BAH-OJNC.js";import"./PhPlus.vue-BQ4oIbMr.js";import"./omniChatStore-BPKAWDFm.js";import"./contracts.generated-xEtU3F0o.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";import"./uuid-BOHQpd3Z.js";import"./PhCopySimple.vue-BrBIEU3L.js";import"./PhSparkle.vue-DL4Askub.js";import"./index-Ca3RhZ0a.js";import"./index-k7fKvFYe.js";import"./ant-design-Qf_x_eQY.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="e6d73791-98de-4989-9837-4c4874a4d649",t._sentryDebugIdIdentifier="sentry-dbid-e6d73791-98de-4989-9837-4c4874a4d649")}catch{}})();const dt=g({__name:"Organization",setup(t){const o=b(),p=z(),m=r(()=>o.params.organizationId),e=r(()=>p.fetchedState?.organization),c=r(()=>e.value?{organizationId:e.value.id}:void 0),s=r(()=>e.value?.billingMetadata);return(I,k)=>{const u=v("RouterView");return i(),a(f,null,{navbar:n(()=>[d(l,{"use-cascader":!0,"cascader-props":c.value},null,8,["cascader-props"])]),content:n(()=>[d(_,null,{default:n(()=>[s.value?(i(),a(w,{key:0,"billing-metadata":s.value,"organization-id":m.value},null,8,["billing-metadata","organization-id"])):y("",!0),(i(),a(u,{key:m.value}))]),_:1})]),_:1})}}});export{dt as default};
//# sourceMappingURL=Organization-C7xWzXWw.js.map
