const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-P0nvN0ke.js","assets/workspaceStore-CRQkfLa2.js","assets/jwt-decode.esm-Dzy-9m8i.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-Drxc-3f9.js","assets/runnerData-CrbzxE5q.js","assets/url-BEAzlLsl.js","assets/colorHelpers-B6IvUH0O.js","assets/OidcLogoutCallback-B8WK4pt9.js","assets/Login-DF1OhGt_.js","assets/Login.vue_vue_type_script_setup_true_lang-Dj9-B2IV.js","assets/OTPInput-CO9ifg8r.js","assets/OTPInput-DkitIIgo.css","assets/Logo-1eOfZ7jQ.js","assets/Logo-D2kepPyK.css","assets/string-CBgg-bcW.js","assets/CircularLoading-Bhmkz1og.js","assets/CircularLoading-BiyobKo3.css","assets/index-k7fKvFYe.js","assets/Login-BYf3W3mQ.css","assets/Login-C1k-SC0u.css","assets/Main-CmmCJQyg.js","assets/PlayerNavbar-C5zYYOcW.js","assets/metadata-CuQD6dTE.js","assets/PhMagnifyingGlass.vue-BEtusSZR.js","assets/PhWebhooksLogo.vue-_naOH9ua.js","assets/LoadingOutlined-hmWUJiw2.js","assets/PhSignOut.vue-BQrRnmv-.js","assets/index-BAH-OJNC.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-eiAcK0Zt.js","assets/Watermark-DU3ArgNw.js","assets/constants-CWkAmIyV.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-DffoWKMw.js","assets/index-CfTFGoKH.js","assets/Home-B6UGln4L.css","assets/Error-BbrxnXoo.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-DACb9zR8.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-BraooUrx.js","assets/FormRunner-Cf3gkB-a.js","assets/Steps-Cs5OBdle.js","assets/index-ByyrlDA1.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-Fkp92u0R.css","assets/redirect-CJTJSBMu.js","assets/asyncComputed-Ab6ltgBh.js","assets/uuid-BOHQpd3Z.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{al as m,am as u,_ as t,an as l}from"./jwt-decode.esm-Dzy-9m8i.js";import{u as p}from"./userStore-Drxc-3f9.js";import{a as _}from"./workspaceStore-CRQkfLa2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="b5e923af-97eb-4fca-82ec-53b0ad3474de",e._sentryDebugIdIdentifier="sentry-dbid-b5e923af-97eb-4fca-82ec-53b0ad3474de")}catch{}})();const E=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"e104c62f508accf2dd75c222109601836192b333"}catch(e){return console.error("Failed to fetch Abstra version:",e),"e104c62f508accf2dd75c222109601836192b333"}},h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-P0nvN0ke.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-B8WK4pt9.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-DF1OhGt_.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-CmmCJQyg.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-eiAcK0Zt.js"),__vite__mapDeps([31,23,2,3,24,25,32,1,4,5,6,7,33,34,35,36,26,37])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-BbrxnXoo.js"),__vite__mapDeps([38,39,40,13,2,3,14,33,1,4,5,6,7,36,41])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BraooUrx.js"),__vite__mapDeps([42,4,2,3,43,10,1,5,6,7,11,12,13,14,15,16,17,18,19,44,45,46,32,33,34,47,48,49,50,51])),meta:{hideLogin:!0}}]}],i=m({history:u("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...d}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...d,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as b,E as g,i as r};
//# sourceMappingURL=router-CPHOdpsP.js.map
