import{aS as r,aT as n,a9 as o,aU as p,aV as c,aW as d,aX as m,aY as f,aZ as u,a_ as s,a$ as b,b0 as g,b1 as l}from"./jwt-decode.esm-Dzy-9m8i.js";import{g as y,r as i}from"./router-CPHOdpsP.js";import{s as w}from"./workspaceStore-CRQkfLa2.js";import{_}from"./App.vue_vue_type_style_index_0_lang-DPV26yPU.js";import"./userStore-Drxc-3f9.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";import"./PlayerConfigProvider-CFzbjL_7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="452bd335-e6a2-4725-a8e6-7f2b7816851c",t._sentryDebugIdIdentifier="sentry-dbid-452bd335-e6a2-4725-a8e6-7f2b7816851c")}catch{}})();class h{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),a=r(),e=n({render:()=>o(_)});p.init(),c(e,i,t),h.init(),e.use(i),e.use(a),e.use(d),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",f),e.component("Message",u),s(e,b),s(e,g),s(e,l)})();
//# sourceMappingURL=player-ZOkq-1vR.js.map
