import{a as i,c as s,k as c,f as d,K as o,Q as a,n as u,m as f}from"./jwt-decode.esm-Dzy-9m8i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="33b3fcfe-90c5-49ac-a226-9e59b4f45e79",e._sentryDebugIdIdentifier="sentry-dbid-33b3fcfe-90c5-49ac-a226-9e59b4f45e79")}catch{}})();const p=i({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,n=s(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),r=s(()=>({position:"absolute",inset:0,overflow:"auto",...t.innerStyle??{}}));return(l,y)=>(d(),c("div",{style:a(n.value),class:o(e.outerClass)},[u("div",{style:a(r.value),class:o(e.innerClass)},[f(l.$slots,"default")],6)],6))}});export{p as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang-C1QmQe57.js.map
