import{h as f,I as l,ae as o}from"./jwt-decode.esm-Dzy-9m8i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d06d08f7-f804-4c54-8cd0-3355b187f3e4",e._sentryDebugIdIdentifier="sentry-dbid-d06d08f7-f804-4c54-8cd0-3355b187f3e4")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){d(e,i,n[i])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var c=function(t,n){var r=a({},t,n.attrs);return f(l,a({},r,{icon:o}),null)};c.displayName="ExclamationCircleOutlined";c.inheritAttrs=!1;export{c as E};
//# sourceMappingURL=ExclamationCircleOutlined-C6jEzd4L.js.map
