import{P as _}from"./PlayerNavbar-C5zYYOcW.js";import{a as g,ak as i,r as h,c as b,k,b as y,e as v,n as w,u as n,h as L,a8 as C,af as I,f as c,aO as N}from"./jwt-decode.esm-Dzy-9m8i.js";import{u as V}from"./workspaceStore-CRQkfLa2.js";import"./userStore-Drxc-3f9.js";import"./metadata-CuQD6dTE.js";import"./PhMagnifyingGlass.vue-BEtusSZR.js";import"./PhWebhooksLogo.vue-_naOH9ua.js";import"./LoadingOutlined-hmWUJiw2.js";import"./PhSignOut.vue-BQrRnmv-.js";import"./index-BAH-OJNC.js";import"./runnerData-CrbzxE5q.js";import"./url-BEAzlLsl.js";import"./colorHelpers-B6IvUH0O.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="44265f98-52d0-4134-ab6f-76071b661bd7",o._sentryDebugIdIdentifier="sentry-dbid-44265f98-52d0-4134-ab6f-76071b661bd7")}catch{}})();const B={class:"main-container"},D={class:"content"},R=g({__name:"Main",setup(o){const e=I(),t=V(),u=i().path,a=h(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[n(t).state.workspace?(c(),y(_,{key:0,"current-path":n(u),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(f)])])}}}),G=N(R,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main-CmmCJQyg.js.map
