import{C as p,_ as i}from"./View.vue_vue_type_script_setup_true_lang-BdUnj-WH.js";import{a as n,ak as s,b as m,f as a,u as d}from"./jwt-decode.esm-Dzy-9m8i.js";import"./router-DFKMVA7Q.js";import"./ts.worker-DQrt9nOI.js";import"./fetch-CweK3EZW.js";import"./record-BJeTf0YU.js";import"./SaveButton-mhd4gVhx.js";import"./ExclamationCircleOutlined-C6jEzd4L.js";import"./CrudView-vbOy7iaa.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-WvGV9CLZ.js";import"./constants-CWkAmIyV.js";import"./url-BEAzlLsl.js";import"./PhDotsThreeVertical.vue-BYkS5j7N.js";import"./index-BliR2HIx.js";import"./asyncComputed-Ab6ltgBh.js";import"./omniChatStore-BPKAWDFm.js";import"./contracts.generated-xEtU3F0o.js";import"./runnerData-CrbzxE5q.js";import"./colorHelpers-B6IvUH0O.js";import"./uuid-BOHQpd3Z.js";import"./PhCopySimple.vue-BrBIEU3L.js";import"./PhPencil.vue-DjQ3qzh8.js";import"./useCodebaseEvents-DDGWyxw3.js";import"./index-k7fKvFYe.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d05483a1-736a-4df7-b306-3d0299e268f9",o._sentryDebugIdIdentifier="sentry-dbid-d05483a1-736a-4df7-b306-3d0299e268f9")}catch{}})();const G=n({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(f,c)=>(a(),m(i,{"env-var-repository":d(e),mode:"console"},null,8,["env-var-repository"]))}});export{G as default};
//# sourceMappingURL=EnvVars-sTTr23vV.js.map
