import{a as n,af as r,J as i,k as s,f as d,h as c,u as f,b7 as p,aO as u}from"./jwt-decode.esm-Dzy-9m8i.js";import{u as l}from"./organizationSwitcher-Dx4c2c2j.js";import"./router-DFKMVA7Q.js";import"./ts.worker-DQrt9nOI.js";import"./organization-ZhAJhUgH.js";import"./tables-B--iEE7v.js";import"./record-BJeTf0YU.js";import"./string-CBgg-bcW.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="7b862b66-cdf5-4a1d-8123-f6d5d0c247e4",o._sentryDebugIdIdentifier="sentry-dbid-7b862b66-cdf5-4a1d-8123-f6d5d0c247e4")}catch{}})();const m={class:"loading-container"},_=n({__name:"RootRedirector",setup(o){const t=l(),a=r();return i(async()=>{const e=await t.selectDefaultOrganization();e.name==="organization"&&e.params?.organizationId?window.location.href=`/organizations/${e.params.organizationId}`:e.name==="onboarding"?window.location.href="/onboarding":a.replace(e)}),(e,g)=>(d(),s("div",m,[c(f(p),{size:"large"})]))}}),k=u(_,[["__scopeId","data-v-a77ce5c1"]]);export{k as default};
//# sourceMappingURL=RootRedirector-C3Bwg-18.js.map
