import{_ as r}from"./logo-BiWG9_W5.js";import{L as o}from"./Logo-1eOfZ7jQ.js";import{a as s,b as a,u as d,f as i}from"./jwt-decode.esm-Dzy-9m8i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ae9f380e-e570-4193-8c1c-50bdc91f80dd",e._sentryDebugIdIdentifier="sentry-dbid-ae9f380e-e570-4193-8c1c-50bdc91f80dd")}catch{}})();const l=s({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(i(),a(o,{"image-url":d(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{l as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-DACb9zR8.js.map
